@@ -247,8 +247,6 @@ struct marpaESLIFSymbol {
   marpaESLIFAction_t            *ifActionp;              /* if-action, only for terminals or lexemes */
   marpaESLIFAction_t            *generatorActionp;       /* generator-action */
   marpaESLIFSymbolOption_t       marpaESLIFSymbolOption;
-  /* Embedded lua - c.f. src/bindings/src/marpaESLIFLua.c */
-  void                          *marpaESLIFLuaSymbolContextp;
   /* When an external meta symbol is created, it duplicates a symbol content */
   short                          contentIsShallowb;
   marpaESLIFGrammar_t           *marpaESLIFGrammarp;     /* Shallow pointer, set by marpaESLIFSymbol_meta_newp() only */
@@ -586,6 +584,7 @@ struct marpaESLIFRecognizer {
 
   /* For lua action callbacks */
   lua_State                   *L;              /* Only owned by the top-level recognizer */
+  marpaESLIFRecognizer_t      *marpaESLIFRecognizerLastInjectedp;
   char                        *actions;        /* Shallow pointer to action "name", depends on action type */
   marpaESLIF_action_t         *actionp;        /* Shallow pointer to action */
 
